@@ -278,7 +278,7 @@ class auto_solutions(object):
                     self.basic_sol.set_distil_text_hyperparam()
                 if self.rows < 1000000: # Add Corex pipelines for rows < 1000K
                     self.addn_sol = copy.deepcopy(basic_sol)
-                    self.addn_sol.initialize_solution('COREXTEXT')
+                    self.addn_sol.initialize_solution('COREXTEXT', self.total_cols, self.metric)
                 if self.rows < 100000: # Add TFIDF pipelines for rows < 100K
                     self.add_TFIDF_solutions()
         elif 'AUDIO' in self.types_present:
@@ -297,7 +297,7 @@ class auto_solutions(object):
         Add solutions for TFIDF text featurization
         """
         basic_sol = solutiondescription.SolutionDescription(self.problem)
-        basic_sol.initialize_solution('TFIDFTEXT')
+        basic_sol.initialize_solution('TFIDFTEXT', self.total_cols, self.metric)
         self.get_primitive_solutions(basic_sol, self.rows)
 
     def get_solutions(self, dataset, problem_metric, timeout_in_min):
